/*
 * Copyright (c) 1996, 2002 Sandro Sigala.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <vector>

#include <fx.h>

#include "fxrepton.h"

struct Episode {
	FXString package;
	FXString name;
	FXString path;
	FXString spritespath;
	int nolevels;
	int id;
	int level;

	Episode() {}
	Episode(const FXString& p, const FXString& n, const FXString& f, int l, int i)
		: package(p), name(n), path(f), spritespath(f), nolevels(l), id(i) {}
};

class GameWidget;
class LegendWindow;
class MapWindow;

class MainWindow: public FXMainWindow {
    	FXDECLARE(MainWindow)

private:
       	FXXPMIcon *bigicon, *smallicon;
       	FXMenuPane *filemenu, *episodemenu, *optionsmenu, *helpmenu;
	FXLabel *time_label, *diamonds_label, *score_label, *level_label;
 	GameWidget *game;
 	LegendWindow *legend;
 	MapWindow *map;
  	FXDataTarget sound_target, zoom_target;
       	FXTimer *timerhandle;
	vector<Episode> episodes;
	Episode episode;
	int zoom;
	FXuint lastkeytime;

	void loadEpisodeList(const FXString& epath);
	void startLevel(const Episode& e, int levelno, bool resetscore);

protected:
	MainWindow();

private:
  	MainWindow(const MainWindow&);
  	MainWindow& operator =(const MainWindow&);

public:
  	long onCmdRestart	(FXObject *, FXSelector, void *);
  	long onCmdRestartEpisode(FXObject *, FXSelector, void *);
  	long onCmdPassword	(FXObject *, FXSelector, void *);
  	long onCmdPause		(FXObject *, FXSelector, void *);
  	long onUpdPause		(FXObject *, FXSelector, void *);
	long onCmdIconify	(FXObject *, FXSelector, void *);
	long onCmdQuit		(FXObject *, FXSelector, void *);
	long onCmdEpisode	(FXObject *, FXSelector, void *);
    	long onUpdEpisode	(FXObject *, FXSelector, void *);
  	long onCmdSound		(FXObject *, FXSelector, void *);
	long onCmdZoom		(FXObject *, FXSelector, void *);
    	long onCmdLegend	(FXObject *, FXSelector, void *);
    	long onUpdLegend	(FXObject *, FXSelector, void *);
    	long onCmdMap		(FXObject *, FXSelector, void *);
    	long onUpdMap		(FXObject *, FXSelector, void *);
    	long onCmdAbout		(FXObject *, FXSelector, void *);
    	long onCmdUp		(FXObject *, FXSelector, void *);
  	long onCmdDown		(FXObject *, FXSelector, void *);
  	long onCmdLeft		(FXObject *, FXSelector, void *);
  	long onCmdRight		(FXObject *, FXSelector, void *);
        long onTimer		(FXObject *, FXSelector, void *);

public:
    	enum {
        	ID_GAME = FXMainWindow::ID_LAST,
		ID_RESTART,
		ID_RESTARTEP,
		ID_PASSWORD,
		ID_PAUSE,
		ID_ICONIFY,
            	ID_QUIT,
            	ID_EPISODE,
            	ID_EPISODELAST = ID_EPISODE+500,
		ID_SOUND,
		ID_ZOOM,
            	ID_LEGEND,
            	ID_MAP,
            	ID_ABOUT,
            	ID_UP,
            	ID_DOWN,
            	ID_LEFT,
            	ID_RIGHT,
            	ID_TIMER,
            	ID_LAST
    	};

public:
	MainWindow(FXApp *app);
	~MainWindow();

  	virtual void create();
};

#endif // !MAINWINDOW_H

